@@ -11,7 +11,7 @@ use File::Basename qw(basename);
 use base 'Exporter';
 our @EXPORT_OK = qw(run);
 
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 our $app;
 
@@ -120,15 +120,14 @@ sub run {
         if ( $options{'byte-offsets'} ) {
             if ( @ARGV == 1 and -f $ARGV[0] ) {
                 my $iter = App::dategrep::Iterator::File->new(
-                    filename  => $ARGV[0],
-                    start     => $start,
-                    end       => $end,
-                    multiline => $options{multiline},
-                    format    => $options{format},
+                    %options,
+                    filename => $ARGV[0],
+                    start    => $start,
+                    end      => $end,
                 );
-                my ( $fh, $byte_beg, $byte_end ) = $iter->byte_offsets();
+                my ( $byte_beg, $byte_end ) = $iter->byte_offsets();
                 if ( not defined $byte_end ) {
-                    $byte_end = ( stat($fh) )[7];
+                    $byte_end = ( stat( $iter->fh ) )[7];
                 }
                 print "$byte_beg $byte_end\n";
                 return 0;
@@ -142,20 +141,18 @@ sub run {
             end       => $end,
         );
 
-        if ( $options{'interleave'} ) {
+        if ( $options{'interleave'} && @ARGV > 1 ) {
             $iterators->interleave();
             return 0;
         }
 
-        if ( $options{'sort-files'} ) {
-            $iterators->sort();
+        if ( $options{'sort-files'} && @ARGV > 1 ) {
+            $iterators->sort;
         }
 
         for my $iter ( $iterators->as_array ) {
             if ($iter) {
-                while ( my $entry = $iter->get_entry ) {
-                    print $entry;
-                }
+                $iter->print;
             }
         }
     };
