@@ -24,6 +24,8 @@ sub BUILDARGS {
         format          => $options{format},
         skip_unparsable => $options{'skip-unparsable'},
     );
+    push @args, blocksize => $options{blocksize} if defined $options{blocksize};
+
     my @iterators;
     for my $filename (@filenames) {
         if ( $filename eq '-' ) {
@@ -46,29 +48,26 @@ sub BUILDARGS {
 sub sort {
     my $self = shift;
 
-    my @timestamps;
-    for my $iterator ( $self->as_array ) {
-        my $entry = $iterator->peek_entry;
+    my @iterators = @{ $self->iterators };
 
-        ## remove all iterators with eof
-        next if not defined $entry;
+    @iterators =
+      sort { $a->next_date <=> $b->next_date }
+      grep { !$_->eof } @iterators;
+
+    $self->iterators( \@iterators );
 
-        my ( $epoch, $error ) = date_to_epoch( $entry, $iterator->format );
-        if ( !$epoch ) {
-            ## TODO Which iterator produced the error?
-            die "No date found in first line: $error\n";
-        }
-        push @timestamps, [ $epoch, $iterator ];
-    }
-    $self->iterators(
-        [ map { $_->[1] } sort { $a->[0] <=> $b->[0] } @timestamps ] );
     return;
 }
 
 sub interleave {
     my $self = shift;
+
     while ( $self->sort, $self->iterators->[0] ) {
-        print $self->iterators->[0]->get_entry;
+        my $until;
+        if ( $self->iterators->[1] ) {
+            $until = $self->iterators->[1]->next_date;
+        }
+        $self->iterators->[0]->print($until);
     }
     return;
 }
